@@ -1,14 +1,15 @@
+from __future__ import annotations
+
 import os
 import re
 from pathlib import Path
-from typing import Optional
 
 from pip._internal.models.direct_url import DIRECT_URL_METADATA_NAME, DirectUrl
 
 from tests.lib import TestPipResult
 
 
-def get_created_direct_url_path(result: TestPipResult, pkg: str) -> Optional[Path]:
+def get_created_direct_url_path(result: TestPipResult, pkg: str) -> Path | None:
     direct_url_metadata_re = re.compile(
         pkg + r"-[\d\.]+\.dist-info." + DIRECT_URL_METADATA_NAME + r"$"
     )
@@ -18,7 +19,7 @@ def get_created_direct_url_path(result: TestPipResult, pkg: str) -> Optional[Pat
     return None
 
 
-def get_created_direct_url(result: TestPipResult, pkg: str) -> Optional[DirectUrl]:
+def get_created_direct_url(result: TestPipResult, pkg: str) -> DirectUrl | None:
     direct_url_path = get_created_direct_url_path(result, pkg)
     if direct_url_path:
         with open(direct_url_path) as f:
